package com.eyuangame.demo

import android.app.Activity
import android.content.Intent
import android.os.Bundle
import androidx.activity.compose.setContent
import androidx.appcompat.app.AppCompatActivity
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.fillMaxSize
import androidx.compose.foundation.layout.padding
import androidx.compose.foundation.rememberScrollState
import androidx.compose.foundation.verticalScroll
import androidx.compose.material.*
import androidx.compose.runtime.Composable
import androidx.compose.ui.Modifier
import androidx.compose.ui.graphics.Color
import androidx.compose.ui.tooling.preview.Preview
import androidx.compose.ui.unit.dp
import androidx.core.view.WindowCompat
import cn.yyxx.support.HostModelUtils
import cn.yyxx.support.hawkeye.ToastUtils
import com.eyuangame.demo.ui.theme.EYuanGameSdkKTXTheme

/**
 * @author #Suyghur.
 * Created on 2021/06/17
 */
class EnvActivity : AppCompatActivity() {

    companion object {
        fun start(activity: Activity) {
            activity.startActivity(Intent(activity, EnvActivity::class.java).addFlags(Intent.FLAG_ACTIVITY_NEW_TASK))
        }
    }

    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        WindowCompat.setDecorFitsSystemWindows(window, false)
        setContent {
            EYuanGameSdkKTXTheme {
                Surface(color = MaterialTheme.colors.background) {
                    EnvPage()
                }
            }
        }
    }

    @Composable
    fun EnvPage() {
        Column(
            modifier = Modifier
                .fillMaxSize()
                .verticalScroll(rememberScrollState()),
        ) {
            Button(
                modifier = Modifier
                    .fillMaxSize()
                    .padding(start = 10.dp, end = 10.dp),
                onClick = { changeModel(HostModelUtils.ENV_TEST) }
            ) {
                Text(text = "00 测试环境")
            }
            Button(modifier = Modifier
                .fillMaxSize()
                .padding(start = 10.dp, end = 10.dp),
                onClick = { changeModel(HostModelUtils.ENV_ONLINE) }
            ) {
                Text(text = "01 正式环境")
            }
        }
    }

    @Preview
    @Composable
    fun PreviewEnv() {
        Surface {
            EnvPage()
        }
    }

    private fun changeModel(model: Int) {
        HostModelUtils.setHostModel(this, model)
        ToastUtils.toastInfo(this, "接口环境切换成功，重启应用后生效")
    }
}