package cn.yyxx.eyuangame.core.impl.center

import android.app.Dialog
import android.content.Context
import android.graphics.Color
import android.graphics.drawable.ColorDrawable
import android.text.InputType
import android.view.Gravity
import android.view.View
import android.view.Window
import android.view.WindowManager
import android.widget.Button
import android.widget.ImageView
import cn.yyxx.eyuangame.core.entity.ResultInfo
import cn.yyxx.eyuangame.core.entity.SdkBackLoginInfo
import cn.yyxx.eyuangame.core.impl.SdkBridgeImpl
import cn.yyxx.eyuangame.core.internal.IRequestCallback
import cn.yyxx.eyuangame.core.network.SdkRequest
import cn.yyxx.eyuangame.core.ui.EventEditText
import cn.yyxx.eyuangame.core.utils.EditTextUtils
import cn.yyxx.support.DensityUtils
import cn.yyxx.support.ResUtils
import cn.yyxx.support.hawkeye.ToastUtils
import org.json.JSONObject

/**
 * @author #Suyghur.
 * Created on 2021/12/23
 */
class ModifyPwdContainer(context: Context) : Dialog(context) {

    private lateinit var ivReturn: ImageView
    private lateinit var eetOldPwd: EventEditText
    private lateinit var eetNewPwd: EventEditText
    private lateinit var btnConfirm: Button

    private var imgShow = 0
    private var imgHide = 0
    private var isShowOldText = false
    private var isShowNewText = false

    init {
        setCanceledOnTouchOutside(true)
        window?.setBackgroundDrawable(ColorDrawable(Color.TRANSPARENT))
        requestWindowFeature(Window.FEATURE_NO_TITLE)
        initView(context)
    }

    private fun initView(context: Context) {
        setContentView(ResUtils.getResId(context, "yyxx_member_modify_pwd", "layout"))

        val attr = window?.attributes as WindowManager.LayoutParams
        attr.height = DensityUtils.dip2px(context, 250f)
        if (SdkBridgeImpl.isLand) {
            attr.width = DensityUtils.getHeightAndWidth(context)[0] / 2
        } else {
            attr.width = DensityUtils.getHeightAndWidth(context)[0] - 80
        }
        attr.gravity = Gravity.CENTER

        imgShow = ResUtils.getResId(context, "yyxx_show_img", "drawable")
        imgHide = ResUtils.getResId(context, "yyxx_hide_img", "drawable")

        ivReturn = findViewById(ResUtils.getResId(context, "yyxx_iv_return", "id"))
        ivReturn.setOnClickListener {
            dismiss()
        }

        eetOldPwd = findViewById(ResUtils.getResId(context, "yyxx_eet_old_pwd", "id"))
        eetOldPwd.apply {
            editText.inputType = InputType.TYPE_TEXT_VARIATION_PASSWORD or InputType.TYPE_CLASS_TEXT
            leftImageView.setBackgroundResource(ResUtils.getResId(context, "yyxx_pwd_img", "drawable"))
            leftImageView.visibility = View.VISIBLE
            editText.setHint(ResUtils.getResId(context, "yyxx_hint_modify_pwd_old", "string"))
            rightImageView.setBackgroundResource(imgShow)
            rightImageView.visibility = View.VISIBLE
            rightImageView.setOnClickListener {
                if (!isShowOldText) {
                    isShowOldText = true
                    rightImageView.setBackgroundResource(imgHide)
                    editText.inputType = InputType.TYPE_TEXT_VARIATION_VISIBLE_PASSWORD
                } else {
                    isShowOldText = false
                    rightImageView.setBackgroundResource(imgShow)
                    editText.inputType = InputType.TYPE_TEXT_VARIATION_PASSWORD or InputType.TYPE_CLASS_TEXT
                }
                editText.setSelection(editText.length())
            }
        }


        eetNewPwd = findViewById(ResUtils.getResId(context, "yyxx_eet_new_pwd", "id"))
        eetNewPwd.apply {
            editText.inputType = InputType.TYPE_TEXT_VARIATION_PASSWORD or InputType.TYPE_CLASS_TEXT
            leftImageView.setBackgroundResource(ResUtils.getResId(context, "yyxx_pwd_img", "drawable"))
            leftImageView.visibility = View.VISIBLE
            editText.setHint(ResUtils.getResId(context, "yyxx_hint_modify_pwd_new", "string"))
            rightImageView.setBackgroundResource(imgShow)
            rightImageView.visibility = View.VISIBLE
            rightImageView.setOnClickListener {
                if (!isShowNewText) {
                    isShowNewText = true
                    rightImageView.setBackgroundResource(imgHide)
                    editText.inputType = InputType.TYPE_TEXT_VARIATION_VISIBLE_PASSWORD
                } else {
                    isShowNewText = false
                    rightImageView.setBackgroundResource(imgShow)
                    editText.inputType = InputType.TYPE_TEXT_VARIATION_PASSWORD or InputType.TYPE_CLASS_TEXT
                }
                editText.setSelection(editText.length())
            }
        }

        btnConfirm = findViewById(ResUtils.getResId(context, "yyxx_btn_confirm", "id"))
        btnConfirm.setOnClickListener {
            callModifyPwd()
        }
    }

    private fun callModifyPwd() {
        val oldPwd = eetOldPwd.editText.text.trim().toString()
        val newPwd = eetNewPwd.editText.text.trim().toString()

        if (!EditTextUtils.filterPwd(oldPwd)) {
            ToastUtils.toastInfo(context, ResUtils.getResString(context, "yyxx_tips_old_pwd_format_error"))
            return
        }

        if (!EditTextUtils.filterPwd(newPwd)) {
            ToastUtils.toastInfo(context, ResUtils.getResString(context, "yyxx_tips_new_pwd_format_error"))
            return
        }

        try {
            with(JSONObject()) {
                put("uid", SdkBackLoginInfo.instance.userId)
                put("pwd", oldPwd)
                put("new_pwd", newPwd)
                SdkRequest.instance.modifyUserPwd(context, this, object : IRequestCallback {
                    override fun onResponse(resultInfo: ResultInfo) {
                        if (resultInfo.code == 1) {
                            ToastUtils.toastInfo(context, resultInfo.msg)
                            dismiss()
                        } else {
                            ToastUtils.toastInfo(context, resultInfo.msg)
                        }
                    }

                })
            }
        } catch (e: Exception) {
            e.printStackTrace()
        }
    }

}